<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Velg et program</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Installerte programmer</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Selvvalgt kommando</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Kommandolinje å kjøre:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Programnavn:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Disse spesielle kodene kan brukes i en kommandolinje:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Representerer et enkelt filnavn&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Representerer flere filnavn&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Representerer en enkelt URI for filen&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Representerer flere URIer&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Hold terminalvinduet åpent etter å ha kjørt kommandoen</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Kjør i terminalemulator</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Bruk valgte program som standardprogram for denne filtypen</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Rediger bokmerker</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Sted</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Legg til element</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Fjern element</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Bruk dra og slipp for å forandre rekkefølge</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Kjør fil</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>K&amp;jør</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Kjør i ter&amp;minal</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Filnavn:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>Filtype:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Mål:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Behandler:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Forbereder...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Framdrift</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Tid igjen:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>Filer behandlet:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Filegenskaper</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Plassering:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Filtype:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>MIME-type:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Størrelse på disken:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Sist endret:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Lenke til:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Åpne med:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Sist brukt:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Opprettet:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Inneholder:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Emblem:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Velg emblem</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Fjern emblem</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Device Usage:</source>
        <translation>Brukt på enheten:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Tillatelser</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Eierskap</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="463"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="476"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Eier:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Filrettigheter</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Annet:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Gjør filen kjørbar</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Les</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Skriv</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Kjør</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="742"/>
        <source>Sticky</source>
        <translation>Blivende</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>SetUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Avansert</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Tilpassing</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="263"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Velg et program for å åpne &quot;%1&quot;-filer</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Tom fil</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>Den valgte mappen &apos;%1&apos; er ikke gyldig</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Åpner...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Ingen undermapper&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="213"/>
        <source>Open in New T&amp;ab</source>
        <translation>Åpne i ny fane</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Åpne i nytt vindu</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="222"/>
        <source>Open in Termina&amp;l</source>
        <translation>Åpne i terminal</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Kopier hit</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Flytt hit</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Lag symbolsk lenke hit</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Kan ikke slippes her</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Nytt bokmerke</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Filen &apos;%1&apos; ser ut til å være en skrivebordsfil.
Hva vil du gjøre med den?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Tekstfilen &apos;%1&apos; ser ut til å være et kjørbart script.
Hva vil du gjøre med det?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Filen &apos;%1&apos; er kjørbar. Vil du kjøre den?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="105"/>
        <source>Go Back</source>
        <translation>Gå tilbake</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="106"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Venstre</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="112"/>
        <source>Go Forward</source>
        <translation>Gå framover</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="113"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Høyre</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="120"/>
        <source>Reload</source>
        <translation>Last på nytt</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="121"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="138"/>
        <source>Create Folder</source>
        <translation>Lag mappe</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="148"/>
        <source>Icon View</source>
        <translation>Symbolvisning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="152"/>
        <source>Thumbnail View</source>
        <translation>Forhåndsvisningsvisning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="156"/>
        <source>Compact View</source>
        <translation>Kompaktvisning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="160"/>
        <source>Detailed List View</source>
        <translation>Detaljert listevisning</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="168"/>
        <source>Icon Sizes</source>
        <translation>Ikonstørrelser</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="170"/>
        <source>Size of big icons:</source>
        <translation>Størrelse på store ikoner:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="177"/>
        <source>Size of small icons:</source>
        <translation>Størrelse på små ikoner:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="184"/>
        <source>Size of thumbnails:</source>
        <translation>Størrelse på miniatyrbilder:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="200"/>
        <source>Show Hidden</source>
        <translation type="unfinished">Vis skjulte</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="212"/>
        <source>Show Thumbnails</source>
        <translation>Vis miniatyrbilder</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="217"/>
        <source>Show File Tooltips</source>
        <translation>Vis filverktøylinje</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="224"/>
        <source>Smooth Scrolling</source>
        <translation>Myk rulling</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="241"/>
        <source>Options</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="574"/>
        <location filename="../filedialog.cpp" line="969"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="574"/>
        <source>Please select a file</source>
        <translation>Vennligst velg en fil</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="616"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 finnes allerede.
Vil du bytte den ut?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="939"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Stien &quot;%1&quot; finnes ikke</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="953"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>&quot;%1&quot; er ikke en mappe</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="959"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>&quot;%1&quot; er ikke en fil</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1111"/>
        <location filename="../filedialog.cpp" line="1219"/>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1114"/>
        <location filename="../filedialog.cpp" line="1227"/>
        <source>&amp;Save</source>
        <translation>&amp;Lagre</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1121"/>
        <source>All Files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="138"/>
        <source>Open File</source>
        <translation>Åpne fil</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Save File</source>
        <translation>Lagre fil</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> px</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Åpne med...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="353"/>
        <source>Many files</source>
        <translation>Mange filer</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="354"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Ønsker du å åpne denne filen?</numerusform>
            <numerusform>Ønsker du å åpne disse %1 filene?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="118"/>
        <source>Other Applications</source>
        <translation>Andre programmer</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="125"/>
        <source>Create &amp;New</source>
        <translation>Lag &amp;ny</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="144"/>
        <source>&amp;Restore</source>
        <translation>&amp;Gjenopprett</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="154"/>
        <source>Cut</source>
        <translation>Klipp ut</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="158"/>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="162"/>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="166"/>
        <location filename="../filemenu.cpp" line="481"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Flytt til papirkurven</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="170"/>
        <source>Rename</source>
        <translation>Gi nytt navn</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Mount</source>
        <translation type="unfinished">Monter</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="240"/>
        <source>Unmount</source>
        <translation type="unfinished">Avmonter</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Eject</source>
        <translation type="unfinished">Spytt ut</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="275"/>
        <source>Extract to...</source>
        <translation>Pakk ut til...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="283"/>
        <source>Extract Here</source>
        <translation>Pakk ut her</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="290"/>
        <source>Compress</source>
        <translation>Komprimer</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="299"/>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="310"/>
        <source>Trust selected executables</source>
        <translation>Stol på valgte programmer</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="311"/>
        <source>Trust this executable</source>
        <translation>Stol på dette programmet</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="416"/>
        <source>Output</source>
        <translation>Resultat</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="148"/>
        <location filename="../filemenu.cpp" line="481"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Noen filer kan ikke bli flyttet til papirkurven fordi det underliggende filsystemet ikke støtter denne operasjonen.
Vil du slette dem istedenfor?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Bekreft</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Slett valgt fil?</numerusform>
            <numerusform>Slett valgte filer?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Flytt valgt fil til papirkurven?</numerusform>
            <numerusform>Flytt valgte filer til papirkurven?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>Flytt filer</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Flytter følgende filer til valgt mappe:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Kopier filer</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Kopierer følgende filer til valgt mappe:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Legg i papirkurv</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Flytter følgende filer til papirkurven:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Slett filer</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Sletter følgende filer:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Skap symbolsk lenke</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Skaper symbolske lenker for følgende filer:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Forandre egenskaper</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Forandrer egenskaper for følgende filer:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Gjenopprett filer fra papirkurven</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Gjenoppretter følgende filer fra papirkurven:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>Vis mappens innhold</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>Vis og forandre mappens innhold</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>Les</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>Les og skriv</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>Forbudt</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>Filer av ulike typer</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <location filename="../filepropsdialog.cpp" line="317"/>
        <location filename="../filepropsdialog.cpp" line="324"/>
        <source>N/A</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="328"/>
        <source>Multiple Files</source>
        <translation>Flere filer</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="405"/>
        <source>%p% used</source>
        <translation>%p% brukt</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="406"/>
        <source>%1 Free of %2</source>
        <translation>%1 ledig på %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="452"/>
        <source>no file</source>
        <translation>ingen fil</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="454"/>
        <source>one file</source>
        <translation>en fil</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="456"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln fil</numerusform>
            <numerusform>%Ln filer</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="490"/>
        <location filename="../filepropsdialog.cpp" line="535"/>
        <source>Select an icon</source>
        <translation>Velg et symbol</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="492"/>
        <location filename="../filepropsdialog.cpp" line="537"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Bilder (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="643"/>
        <source>Apply changes</source>
        <translation>Utfør endringer</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="644"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Vil du utføre disse endringene for alle filer og undermapper?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>Du bør legge til minst en mappe å søke i.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Velg en mappe</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="479"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Kan ikke kopiere en mappe til seg selv!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="530"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Kan ikke lage en lenke på en fremmed filsystem-type</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="57"/>
        <source>Empty Trash</source>
        <translation type="unfinished">Tøm papirkurv</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Create &amp;New</source>
        <translation>Skap &amp;ny</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="74"/>
        <source>&amp;Paste</source>
        <translation>&amp;Lim inn</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="87"/>
        <source>Select &amp;All</source>
        <translation>Velg &amp;alt</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="91"/>
        <source>Invert Selection</source>
        <translation>Inverterter markering</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="98"/>
        <source>Sorting</source>
        <translation>Sortering</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="103"/>
        <source>Show Hidden</source>
        <translation>Vis skjulte</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="138"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Mappe&amp;egenskaper</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="181"/>
        <source>Output</source>
        <translation>Resultat</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="203"/>
        <source>By File Name</source>
        <translation>Etter filnavn</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="204"/>
        <source>By Modification Time</source>
        <translation>Etter sist endret</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By Creation Time</source>
        <translation>Etter opprettelse</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="208"/>
        <source>By Deletion Time</source>
        <translation>Etter tid slettet</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="211"/>
        <source>By File Size</source>
        <translation>Etter størrelse</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="212"/>
        <source>By File Type</source>
        <translation>Etter type</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Owner</source>
        <translation>Etter eier</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Group</source>
        <translation>Etter filgruppe</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="220"/>
        <source>Ascending</source>
        <translation>Økende</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="225"/>
        <source>Descending</source>
        <translation>Minskende</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="242"/>
        <source>Folder First</source>
        <translation>Mapper først</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="250"/>
        <source>Hidden Last</source>
        <translation>Skjult sist</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="258"/>
        <source>Case Sensitive</source>
        <translation>Forskjell på STORE og små bokstaver</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="304"/>
        <source>Location:</source>
        <translation>Plassering:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="308"/>
        <source>File type:</source>
        <translation>Filtype:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="313"/>
        <source>File size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="317"/>
        <source>Last modified:</source>
        <translation>Sist endret:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="318"/>
        <source>Last accessed:</source>
        <translation>Sist brukt:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>N/A</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>Created:</source>
        <translation>Opprettet:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="326"/>
        <source>Owner:</source>
        <translation>Eier:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="327"/>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="394"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="397"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="400"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="403"/>
        <source>Modified</source>
        <translation>Sist endret</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="406"/>
        <source>Created</source>
        <translation>Opprettet</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="409"/>
        <source>Deleted</source>
        <translation>Slettet</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="412"/>
        <source>Owner</source>
        <translation>Eier</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="415"/>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="406"/>
        <source>Auto-resize columns</source>
        <translation>Gi ny størrelse til kolonner automatisk</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="423"/>
        <source>Visible Columns</source>
        <translation>Synlige kolonner</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Koble til</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="130"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Rediger sti</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="133"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Kopier sti</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="47"/>
        <source>Places</source>
        <translation>Steder</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="55"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="61"/>
        <source>Computer</source>
        <translation>Datamaskin</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="69"/>
        <source>Applications</source>
        <translation>Programmer</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="78"/>
        <source>Network</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Devices</source>
        <translation>Enheter</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="137"/>
        <source>Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="228"/>
        <source>Trash</source>
        <translation>Papirkurv</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="482"/>
        <source>Open in New Tab</source>
        <translation>Åpne i ny fane</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="485"/>
        <source>Open in New Window</source>
        <translation>Åpne i nytt vindu</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="497"/>
        <source>Empty Trash</source>
        <translation>Tøm papirkurv</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="517"/>
        <location filename="../placesview.cpp" line="579"/>
        <source>Hide</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="534"/>
        <source>Move Bookmark Up</source>
        <translation>Flytt bokmerke oppover</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="541"/>
        <source>Move Bookmark Down</source>
        <translation>Flytt bokmerke nedover</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="546"/>
        <source>Rename Bookmark</source>
        <translation>Gi nytt navn til bokmerke</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="550"/>
        <source>Remove Bookmark</source>
        <translation>Slett bokmerke</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="560"/>
        <location filename="../placesview.cpp" line="593"/>
        <source>Unmount</source>
        <translation>Løs ut</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="564"/>
        <source>Mount</source>
        <translation>Last inn</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="570"/>
        <source>Eject</source>
        <translation>Spytt ut</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="605"/>
        <source>Show All Entries</source>
        <translation>Vis alle</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Type: %1
Størrelse %2
Sist endret: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Type: %1
Sist endret: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Skriv over</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>&amp;Gi nytt navn</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="108"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Filen kan ikke overskrive seg selv.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Velg et annet navn.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>Lister</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>Mappetre</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Kan ikke gjenopprette filen &apos;%s&apos;: original plassering ukjent</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Last inn</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Koble til &amp;anonymt</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Koble til som &amp;bruker:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>&amp;Brukernavn:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Passord:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domene:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Glem passord &amp;umiddelbart</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation>Husk passordet for &amp;denne økten</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Husk &amp;alltid</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="163"/>
        <source>Rename File</source>
        <translation>Gi nytt filnavn</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Please enter a new name:</source>
        <translation>Skriv inn nytt navn:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="119"/>
        <location filename="../filepropsdialog.cpp" line="669"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="147"/>
        <location filename="../utilities.cpp" line="286"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="223"/>
        <source>Create Folder</source>
        <translation>Lag mappe</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="224"/>
        <source>Create File</source>
        <translation>Lag fil</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="228"/>
        <source>Please enter a new file name:</source>
        <translation>Skriv inn et nytt filnavn:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="229"/>
        <source>New text file</source>
        <translation>Ny tekstfil</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="233"/>
        <source>Please enter a new folder name:</source>
        <translation>Skriv inn et nytt mappenavn:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="234"/>
        <source>New folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="239"/>
        <source>Enter a name for the new %1:</source>
        <translation>Skriv inn et nytt navn for den nye %1:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="687"/>
        <source>Custom Icon Error</source>
        <translation>Feil med selvvalgt symbol</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Stien er ikke lastet inn.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Ugyldig skrivebordsfil: &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Ingen program er satt til å åpne &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Kan ikke sette arbeidsmappen til &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Identifikasjon: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>Ingen</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Bekreft for å bytte filer</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Det er allerede en fil med samme navn på dette stedet.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Ønsker du å bytte ut den eksisterende filen?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>med følgende fil?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Filnavn:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Bruk dette valget på alle eksisterende filer</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Søk filer</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Navn/Plassering</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Filnavnmønstre:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="41"/>
        <source>*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Bruk regular expression</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="68"/>
        <source>Places to Search:</source>
        <translation>Steder å søke:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="81"/>
        <source>&amp;Add</source>
        <translation>&amp;Legg til</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="93"/>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="129"/>
        <source>Search for hidden files</source>
        <translation>Søk etter skjulte filer</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="140"/>
        <source>File Type</source>
        <translation>Filtype</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="146"/>
        <source>Only search for files of following types:</source>
        <translation>Bare søk etter følgende filtyper:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="152"/>
        <source>Text files</source>
        <translation>Tekstfiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="159"/>
        <source>Image files</source>
        <translation>Bildefiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="166"/>
        <source>Audio files</source>
        <translation>Lydfiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="173"/>
        <source>Video files</source>
        <translation>Videofiler</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="180"/>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="187"/>
        <source>Folders</source>
        <translation>Mapper</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="211"/>
        <source>Content</source>
        <translation>Innhold</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="217"/>
        <source>File contains:</source>
        <translation>Fil inneholder:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Bruk regular expression</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="260"/>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="266"/>
        <source>File Size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="295"/>
        <source>Larger than:</source>
        <translation>Større enn:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="309"/>
        <location filename="../filesearch.ui" line="339"/>
        <source>Bytes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="314"/>
        <location filename="../filesearch.ui" line="344"/>
        <source>KiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="319"/>
        <location filename="../filesearch.ui" line="349"/>
        <source>MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="324"/>
        <location filename="../filesearch.ui" line="354"/>
        <source>GiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="274"/>
        <source>Smaller than:</source>
        <translation>Mindre enn:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="48"/>
        <source>Case sensitive</source>
        <translation>Forskjell på små og store bokstaver</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="122"/>
        <source>Search in subdirectories</source>
        <translation>Søk i undermapper</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="226"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Forskjell på små og &amp;store bokstaver</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="370"/>
        <source>Last Modified Time:</source>
        <translation>Sist endret:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="378"/>
        <source>Earlier than:</source>
        <translation>Før:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Later than:</source>
        <translation>Etter:</translation>
    </message>
</context>
</TS>
